Copy the current schema to this directory at:
schema-latest.graphql

    For now we don't want this checked in

https://github.com/wandb/core/releases/tag/local%2Fv0.57.4
https://github.com/wandb/core/blob/37f710fec9e989b4725e38daa68d7c5680468632/services/gorilla/schema.graphql
